======
Events
======

* **Webhook** - updates handling via webhook.
* **Invoice polling** - invoice updates handling via polling.
* **Check polling** - check updates handling via polling.
* **Polling config** - configuration for update requests

.. toctree::

    routers
    webhook
    invoice_polling
    check_polling
    filters
    polling_config
    payload_data